:sd_hide_title:
.. grid:: 1

    .. grid-item-card:: PyXMake as a webservice

        Learn how to use PyXMake endpoints using web requests.
---
API
---
PyXMake's web services can be run locally or on self-managed servers. `fastapi`_ is used to define the endpoints. To start the API on the server, please use

.. code-block:: console

    $ pyxmake start

.. _fastapi: https://fastapi.tiangolo.com/
.. toctree::
   :hidden:

   self